@@ -10,4 +10,6 @@ from .files import *
 from .os import *
 from .path import *
 from .string import *
-from .time import *
\ No newline at end of file
+from .time import *
+from .delay import *
+from .stdout import *
\ No newline at end of file
